@@ -25,7 +25,7 @@ bool Methods::scrJoin(void)
 	Event event;
 
 	state.timeout = 0;
-	state.join.peer = getSid(var_pid);
+	state.join.peer = getSid(var_joined);
 	state.join.dtmf = false;
 
 	if(!state.join.peer)
@@ -137,7 +137,10 @@ bool Methods::scrStart(void)
 	if(sym)
 		ScriptInterp::commit(sym, child->getExternal("session.id"));
 	if(!stricmp(line->cmd, "connect"))
+	{
 		strcpy(state.tone.sessionid, child->getExternal("session.id"));
+		strcpy(var_joined, child->getExternal("session.id"));
+	}
 
 	while(NULL != (cp = getOption(NULL)))
 	{
