@@ -445,6 +445,7 @@ void BayonneDriver::stop(void)
         BayonneDriver *driver = firstDriver;
 	unsigned ts = 0;
 	Event event;
+	timeout_t hangup_timer = 0;
 
 	slog.notice("driver(s) stopping...");
 
@@ -458,6 +459,10 @@ void BayonneDriver::stop(void)
 		s->enter();
 		if(!s->isIdle())
 		{
+			if(s->driver->hangup_timer > hangup_timer)
+				hangup_timer = s->driver->hangup_timer;
+
+			hangup_timer = s->driver->hangup_timer;
 			memset(&event, 0, sizeof(event));
 			event.id = STOP_SCRIPT;
 			s->postEvent(&event);
@@ -465,7 +470,8 @@ void BayonneDriver::stop(void)
 		s->leave();
 	}
 
-	Thread::sleep(1000);
+	if(hangup_timer)
+		Thread::sleep(hangup_timer + 60);
 	
         while(driver)
         {
