@@ -36,7 +36,7 @@ static Keydata::Define driver[] = {
 	{"priority", "0"},
 	{"encoding", "mulaw"},
 	{"framing", "20"},
-	{"timer", "50"},
+	{"timer", "500"},
 	{"payload", "0"},
 	{"dtmf", "101"},
 	{"inband", "false"},
@@ -827,7 +827,6 @@ void Driver::stopDriver(void)
 			}
 			endImage(img);
 		}
-		Thread::sleep(500);
 		thread = SIPThread::first;
 		while(thread)
 		{
@@ -1649,23 +1648,28 @@ void Driver::run(void)
 	timeout_t expires;
 	unsigned thread = ++instance;
 	time_t now;
+	time_t last = 0;
 
 	Bayonne::waitLoaded();
 
 	for(;;)
         {
 		sevent = eXosip_event_wait(0, event_timer);
-/*		eXosip_lock();
-		eXosip_automatic_action();
-		eXosip_unlock();
-*/
 		Thread::yield();
 
 		if(exiting)
 			Thread::sync();
 
 		if(!sevent)
+		{
+			eXosip_lock();
+			time(&now);
+			if(now != last)
+				eXosip_automatic_action();
+			last = now;
+			eXosip_unlock();
 			continue;
+		}
 
 		slog.debug("sip: event %04x; cid=%d, did=%d, rid=%d, instance=%d",
 			sevent->type, sevent->cid, sevent->did, sevent->rid, thread);
@@ -1720,6 +1724,7 @@ void Driver::run(void)
 				setAuthentication(reg, sevent->response);
 				server->leave();
 				eXosip_lock();
+				time(&last);
 				eXosip_automatic_action();
 				eXosip_unlock();
 				break;
@@ -2019,12 +2024,14 @@ killit:
 			case AUTH_REQUIRED:
 				getAuthentication(session, sevent->response);
 				eXosip_lock();
+				time(&last);
 				eXosip_automatic_action();
 				eXosip_unlock();
 				break;
 			case UNAUTHORIZED:
 				getAuthentication(session, sevent->response);
 				eXosip_lock();
+				time(&last);
 				eXosip_automatic_action();
 				eXosip_unlock();
 				break;
