@@ -94,6 +94,8 @@ public:
 	volatile short active_calls;
 	time_t updated;
 	bool active;
+	unsigned long sequence;
+
 	enum
 	{
 		P_AVAILABLE = 0,
@@ -134,6 +136,9 @@ public:
 
 	bool isActive(void);
 	void add(ScriptImage *img);
+
+	inline unsigned long getSequence(void)
+		{return traffic->sequence;};
 };
 	
 class SIPThread : public Thread
