@@ -105,6 +105,16 @@ Session::~Session()
 	handle = -1;
 }
 
+timeout_t Session::audioFraming(void)
+{
+	return 20;
+}
+
+const char *Session::audioEncoding(void)
+{
+	return Audio::getName(Audio::mulawAudio);
+}
+
 bool Session::peerAudio(Audio::Encoded encoded)
 {
 	enter();
@@ -158,6 +168,8 @@ void Session::queEvent(Event *event)
 		e.type = VPB_DIALEND;
 		e.handle = handle;
 		vpb_put_event(&e);
+	default:
+		break;
 	};
 }
 
@@ -240,8 +252,9 @@ bool Session::enterDial(Event *event)
 		else
 			vpb_dial_async(handle, (char *)state.join.dial);
 		return true;
+	default:
+		return false;
 	}
-	return false;
 }
 
 bool Session::enterRinging(Event *event)
@@ -254,8 +267,9 @@ bool Session::enterRinging(Event *event)
 
 		thread = new Callerid(this, handle);
 		thread->start();
+	default:
+		return false;
 	}
-	return false;
 }
 
 const char *Session::checkAudio(bool live)
